==> aws-cdk-lib-2.0.0-rc.20-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/ForwardOptions.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2;

/**
 * (experimental) Options for `ListenerAction.forward()`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-09-01T10:26:21.857Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_elasticloadbalancingv2.ForwardOptions")
@software.amazon.jsii.Jsii.Proxy(ForwardOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ForwardOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) For how long clients should be directed to the same target group.
     * <p>
     * Range between 1 second and 7 days.
     * <p>
     * Default: - No stickiness
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.Duration getStickinessDuration() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ForwardOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ForwardOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<ForwardOptions> {
        private software.amazon.awscdk.Duration stickinessDuration;

        /**
         * Sets the value of {@link ForwardOptions#getStickinessDuration}
         * @param stickinessDuration For how long clients should be directed to the same target group.
         *                           Range between 1 second and 7 days.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder stickinessDuration(software.amazon.awscdk.Duration stickinessDuration) {
            this.stickinessDuration = stickinessDuration;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ForwardOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public ForwardOptions build() {
            return new Jsii$Proxy(stickinessDuration);
        }
    }

    /**
     * An implementation for {@link ForwardOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ForwardOptions {
        private final software.amazon.awscdk.Duration stickinessDuration;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.stickinessDuration = software.amazon.jsii.Kernel.get(this, "stickinessDuration", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.Duration.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.Duration stickinessDuration) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.stickinessDuration = stickinessDuration;
        }

        @Override
        public final software.amazon.awscdk.Duration getStickinessDuration() {
            return this.stickinessDuration;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getStickinessDuration() != null) {
                data.set("stickinessDuration", om.valueToTree(this.getStickinessDuration()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_elasticloadbalancingv2.ForwardOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ForwardOptions.Jsii$Proxy that = (ForwardOptions.Jsii$Proxy) o;

            return this.stickinessDuration != null ? this.stickinessDuration.equals(that.stickinessDuration) : that.stickinessDuration == null;
        }

        @Override
        public final int hashCode() {
            int result = this.stickinessDuration != null ? this.stickinessDuration.hashCode() : 0;
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/ForwardOptions.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2;

/**
 * Options for `ListenerAction.forward()`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.*;
 * import software.amazon.awscdk.services.elasticloadbalancingv2.*;
 * ForwardOptions forwardOptions = ForwardOptions.builder()
 *         .stickinessDuration(Duration.minutes(30))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:09.970Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_elasticloadbalancingv2.ForwardOptions")
@software.amazon.jsii.Jsii.Proxy(ForwardOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ForwardOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * For how long clients should be directed to the same target group.
     * <p>
     * Range between 1 second and 7 days.
     * <p>
     * Default: - No stickiness
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.Duration getStickinessDuration() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ForwardOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ForwardOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ForwardOptions> {
        software.amazon.awscdk.Duration stickinessDuration;

        /**
         * Sets the value of {@link ForwardOptions#getStickinessDuration}
         * @param stickinessDuration For how long clients should be directed to the same target group.
         *                           Range between 1 second and 7 days.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder stickinessDuration(software.amazon.awscdk.Duration stickinessDuration) {
            this.stickinessDuration = stickinessDuration;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ForwardOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ForwardOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ForwardOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ForwardOptions {
        private final software.amazon.awscdk.Duration stickinessDuration;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.stickinessDuration = software.amazon.jsii.Kernel.get(this, "stickinessDuration", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.Duration.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.stickinessDuration = builder.stickinessDuration;
        }

        @Override
        public final software.amazon.awscdk.Duration getStickinessDuration() {
            return this.stickinessDuration;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getStickinessDuration() != null) {
                data.set("stickinessDuration", om.valueToTree(this.getStickinessDuration()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_elasticloadbalancingv2.ForwardOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ForwardOptions.Jsii$Proxy that = (ForwardOptions.Jsii$Proxy) o;

            return this.stickinessDuration != null ? this.stickinessDuration.equals(that.stickinessDuration) : that.stickinessDuration == null;
        }

        @Override
        public final int hashCode() {
            int result = this.stickinessDuration != null ? this.stickinessDuration.hashCode() : 0;
            return result;
        }
    }
}
